==> com.liferay.notification.service-1.0.65-sources.jar: com/liferay/notification/internal/search/NotificationTemplateModelSearchConfigurator.java <==
/**
 * SPDX-FileCopyrightText: (c) 2023 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.notification.internal.search;

import com.liferay.notification.model.NotificationTemplate;
import com.liferay.portal.kernel.search.Field;
import com.liferay.portal.search.spi.model.index.contributor.ModelIndexerWriterContributor;
import com.liferay.portal.search.spi.model.registrar.ModelSearchConfigurator;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Gustavo Lima
 */
@Component(service = ModelSearchConfigurator.class)
public class NotificationTemplateModelSearchConfigurator
	implements ModelSearchConfigurator<NotificationTemplate> {

	@Override
	public String getClassName() {
		return NotificationTemplate.class.getName();
	}

	@Override
	public String[] getDefaultSelectedFieldNames() {
		return new String[] {
			Field.COMPANY_ID, Field.ENTRY_CLASS_NAME, Field.ENTRY_CLASS_PK,
			Field.UID
		};
	}

	@Override
	public String[] getDefaultSelectedLocalizedFieldNames() {
		return new String[] {Field.NAME};
	}

	@Override
	public ModelIndexerWriterContributor<NotificationTemplate>
		getModelIndexerWriterContributor() {

		return _modelIndexWriterContributor;
	}

	@Reference(
		target = "(indexer.class.name=com.liferay.notification.model.NotificationTemplate)"
	)
	private ModelIndexerWriterContributor<NotificationTemplate>
		_modelIndexWriterContributor;

}

==> com.liferay.notification.service-1.0.78-sources.jar: com/liferay/notification/internal/search/NotificationTemplateModelSearchConfigurator.java <==
/**
 * SPDX-FileCopyrightText: (c) 2023 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.notification.internal.search;

import com.liferay.notification.internal.search.spi.model.index.contributor.NotificationTemplateModelIndexerWriterContributor;
import com.liferay.notification.model.NotificationTemplate;
import com.liferay.notification.service.NotificationTemplateLocalService;
import com.liferay.portal.kernel.search.Field;
import com.liferay.portal.search.batch.DynamicQueryBatchIndexingActionableFactory;
import com.liferay.portal.search.spi.model.index.contributor.ModelIndexerWriterContributor;
import com.liferay.portal.search.spi.model.registrar.ModelSearchConfigurator;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Gustavo Lima
 */
@Component(service = ModelSearchConfigurator.class)
public class NotificationTemplateModelSearchConfigurator
	implements ModelSearchConfigurator<NotificationTemplate> {

	@Override
	public String getClassName() {
		return NotificationTemplate.class.getName();
	}

	@Override
	public String[] getDefaultSelectedFieldNames() {
		return new String[] {
			Field.COMPANY_ID, Field.ENTRY_CLASS_NAME, Field.ENTRY_CLASS_PK,
			Field.UID
		};
	}

	@Override
	public String[] getDefaultSelectedLocalizedFieldNames() {
		return new String[] {Field.NAME};
	}

	@Override
	public ModelIndexerWriterContributor<NotificationTemplate>
		getModelIndexerWriterContributor() {

		return _modelIndexWriterContributor;
	}

	@Activate
	protected void activate() {
		_modelIndexWriterContributor =
			new NotificationTemplateModelIndexerWriterContributor(
				_dynamicQueryBatchIndexingActionableFactory,
				_notificationTemplateLocalService);
	}

	@Reference
	private DynamicQueryBatchIndexingActionableFactory
		_dynamicQueryBatchIndexingActionableFactory;

	private ModelIndexerWriterContributor<NotificationTemplate>
		_modelIndexWriterContributor;

	@Reference
	private NotificationTemplateLocalService _notificationTemplateLocalService;

}
